@@ -83,7 +83,7 @@ def main_standalone( argc, argv ):
         CoNum, meanCoNum = ref.CourantNo( mesh, phi, runTime )
         
         fluid.correct()
-        UEqn = ref.fvm.ddt( U ) + ref.fvm.div( phi, U ) - ref.fvm.laplacian( fluid.ext_nu(), U )
+        UEqn = ref.fvm.ddt( U ) + ref.fvm.div( phi, U ) - ref.fvm.laplacian( fluid.ext_nu(), U ) - ( ref.fvc.grad( U )  & ref.fvc.grad( fluid.ext_nu() ) )
         
         ref.solve( UEqn == -ref.fvc.grad( p ) )
         
@@ -130,7 +130,7 @@ def main_standalone( argc, argv ):
 
 #--------------------------------------------------------------------------------------
 from Foam import FOAM_VERSION
-if FOAM_VERSION( ">=", "020000" ):
+if FOAM_VERSION( ">=", "020101" ):
    if __name__ == "__main__" :
      import sys, os
      argv = sys.argv
@@ -138,6 +138,6 @@ if FOAM_VERSION( ">=", "020000" ):
      pass
    pass
 else:
-   ref.ext_Info() << "\n\n To use this solver it is necessary to SWIG OpenFOAM-2.0.0 or higher\n"
+   ref.ext_Info() << "\n\n To use this solver it is necessary to SWIG OpenFOAM-2.1.1 or higher\n"
    pass
 
